"""
Soft Potato pip version

"""

__version__ = "0.11"
__author__ = 'Oliver Rodriguez'

__all__ = ['tech', 'calc', 'plot']